<?php
// CSC 331 ASSIGNMENT - Java code as a string
$mycode = <<<JAVA
import java.util.Random;
public class DiceAndPoisson {
    public static int dice() {
        Random random = new Random();
        return random.nextInt(6) + 1;
    }
    public static double poisson(int k, double timeInterval, double eventsPerMinute) {
        if (k < 0 || timeInterval < 0 || eventsPerMinute <= 0) {
            throw new IllegalArgumentException("Invalid input values");
        }
        double lambda = eventsPerMinute * timeInterval;
        double numerator = Math.exp(-lambda) * Math.pow(lambda, k);
        int factorial = 1;
        for (int i = 1; i <= k; i++) {
            factorial *= i;
        }
        return numerator / factorial;
    }
    public static void main(String[] args) {
        System.out.println("Simulating the throw of a fair die:");
        for (int i = 0; i < 10; i++) {
            int result = dice();
            System.out.println("Throw " + (i + 1) + ": " + result);
        }
        double eventsPerMinute = 1.6;
        double timeInterval = 1;
        System.out.println("\nCalculating the Poisson distribution:");
        for (int k = 0; k <= 5; k++) {
            double probability = poisson(k, timeInterval, eventsPerMinute);
            System.out.println("P(" + k + "," + timeInterval + ") = " + probability);
        }
    }
}
JAVA;

// Keywords used in Java
$keywords = [
    "abstract",
    "assert",
    "boolean",
    "break",
    "byte",
    "case",
    "catch",
    "char",
    "class",
    "const",
    "continue",
    "default",
    "do",
    "double",
    "else",
    "enum",
    "extends",
    "final",
    "finally",
    "float",
    "for",
    "goto",
    "if",
    "implements",
    "import",
    "instanceof",
    "int",
    "interface",
    "long",
    "native",
    "new",
    "package",
    "private",
    "protected",
    "public",
    "return",
    "short",
    "static",
    "strictfp",
    "super",
    "switch",
    "synchronized",
    "this",
    "throw",
    "throws",
    "transient",
    "try",
    "void",
    "volatile",
    "while"
];

// Regular expressions for lexicons in Java
$myexpressions = [
    "keywords" => "/\b(" . implode("|", $keywords) . ")\b/",
    "identifiers" => "/\b[A-Za-z_][A-Za-z0-9_]*\b/",
    "literals" => "/\b\d+(\.\d+)?\b|\"[^\"]*\"/",
    "operators" => "/[\+\-\*\/=<>!&|]+/",
    "separators" => "/[{}()\[\];,]/"
];

// Store lexicons
$mylexicons = [
    "keywords" => [],
    "identifiers" => [],
    "literals" => [],
    "operators" => [],
    "separators" => []
];

// Extract lexicons from the Java code
foreach ($myexpressions as $newcategory => $expression) {
    preg_match_all($expression, $mycode, $matches);
    $mylexicons[$newcategory] = array_count_values($matches[0]);
}

?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>AYODELE YAHYAH OLUWASEGUN - Java Code Lexicon Analysis</title>
    <!-- Bootstrap CSS -->
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
</head>

<body>
    <div class="container my-5">
        <div class="row">
            <div class="col-md-12">
                <div class="card">
                    <div class="card-header text-center">
                        <h1>University of Ibadan - CSC 331 Assignment</h1>
                        <h4>Solution to CSC 331 Java Code Lexicon Analysis</h4>
                    </div>
                    <div class="card-body">
                        <p class="text-center"><b>Question:</b> Using any programming language of your choice, analyze the Java snippet below to extract all the different categories of lexicons. For each category, present the output including the type, a list of lexicons within that category, and the total count for each category.</p>

                        <h5><strong>NAME: AYODELE YAHYAH OLUWASEGUN</strong></h5>
                        <h5><strong>MATRIC NUMBER: E043417</strong></h5>
                        <h5><strong>LEVEL: 500LEVEL</strong></h5>
                        <br>

                        <h5><strong>My Java Code Lexicon Analysis are as follows:</strong></h5>

                        <?php
                        $counter = 1; 
                        foreach ($mylexicons as $newcategory => $items) {
                            echo "<div class='mb-4'>";
                            echo "<h6><strong>$counter. " . ucfirst($newcategory) . " (" . count($items) . ")</strong></h6>";
                            $serial = 1; 
                            echo "<ul>";
                            foreach ($items as $mylexicon => $count) {
                                echo "<li>$serial. <strong>$mylexicon</strong> (count: $count)</li>";
                                $serial++;
                            }
                            echo "</ul>";
                            echo "</div>";
                            $counter++;
                        }
                        ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Bootstrap JS and dependencies -->
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.0/dist/umd/popper.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>

</html>