<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Super Admin Signup</title>
    <link rel="stylesheet" href="plugins/fontawesome-free/css/all.min.css">
    <link rel="stylesheet" href="dist/css/adminlte.min.css">
    <link rel="stylesheet" href="plugins/sweetalert2-theme-bootstrap-4/bootstrap-4.min.css">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>

    <style>
        /* Gradient Animated Background */
        body {
            background: linear-gradient(-45deg, #ff9a9e, #fad0c4, #ffdde1, #b5e0fa);
            background-size: 400% 400%;
            animation: gradientBG 8s ease infinite;
            display: flex;
            align-items: center;
            justify-content: center;
            height: 100vh;
            margin: 0;
        }
        
        @keyframes gradientBG {
            0% { background-position: 0% 50%; }
            50% { background-position: 100% 50%; }
            100% { background-position: 0% 50%; }
        }

        /* Enlarged and Styled Signup Card */
        .login-box {
            width: 450px;
        }

        .card {
            border-radius: 15px;
            box-shadow: 0px 8px 16px rgba(0, 0, 0, 0.2);
            animation: fadeIn 0.8s ease-in-out;
        }

        @keyframes fadeIn {
            from { opacity: 0; transform: translateY(-20px); }
            to { opacity: 1; transform: translateY(0); }
        }

        .card-header {
            background: #186F45;
            color: white;
            text-align: center;
            font-weight: bold;
            font-size: 1.5rem;
            padding: 15px;
            border-top-left-radius: 15px;
            border-top-right-radius: 15px;
        }

        /* Rounded Inputs */
        .form-control {
            border-radius: 8px;
            padding: 10px;
            font-size: 1rem;
        }

        .btn {
            border-radius: 8px;
            font-size: 1rem;
            font-weight: bold;
            padding: 10px;
            transition: all 0.3s ease-in-out;
        }

        /* Primary Button Styling */
        .btn-primary {
            background: #186F45;
            border: none;
        }

        .btn-primary:hover {
            background: #125530;
            transform: scale(1.05);
        }

        /* Info Button Styling */
        .btn-info {
            background: #17a2b8;
            border: none;
        }

        .btn-info:hover {
            background: #117a8b;
            transform: scale(1.05);
        }

        /* Hide form initially */
        #accountDetails {
            display: none;
            animation: fadeIn 0.5s ease-in-out;
        }

    </style>
</head>
<body>
    <div class="login-box">
        <div class="card">
            <div class="card-header text-center">
                Super Admin Signup
            </div>
            <div class="card-body">
                <form id="signupForm">
                    <div class="form-group">
                        <label>Email or Phone</label>
                        <input type="text" id="identifier" name="identifier" class="form-control" required>
                    </div>
                    <div id="accountDetails">
                        <div class="form-group">
                            <label>Full Name</label>
                            <input type="text" id="fullname" class="form-control" disabled>
                        </div>
                        <div class="form-group">
                            <label>Zone</label>
                            <input type="text" id="zone" class="form-control" disabled>
                        </div>
                        <div class="form-group">
                            <label>Region</label>
                            <input type="text" id="region" class="form-control" disabled>
                        </div>
                        <div class="form-group">
                            <label>Create Password</label>
                            <input type="password" id="password" name="password" class="form-control" required>
                        </div>
                        <button type="submit" class="btn btn-primary btn-block">Register</button>
                    </div>
                    <button type="button" id="checkUser" class="btn btn-info btn-block">Check Account</button>
                </form>
            </div>
        </div>
    </div>

<script>
$(document).ready(function () {
    $('#checkUser').click(function () {
        let identifier = $('#identifier').val();
        if (identifier === '') {
            Swal.fire("Error", "Enter email or phone number", "error");
            return;
        }
        
        $.ajax({
            url: 'check_user.php',
            type: 'POST',
            data: { identifier: identifier },
            dataType: 'json',
            success: function (response) {
                if (response.status === 'exists') {
                    $('#fullname').val(response.fullname);
                    $('#zone').val(response.zone);
                    $('#region').val(response.region);
                    $('#accountDetails').slideDown();
                    $('#checkUser').hide();
                } else {
                    Swal.fire("Error", "Account not found. Please use a valid email or phone number.", "error");
                }
            }
        });
    });

    $('#signupForm').submit(function (e) {
        e.preventDefault();
        $.ajax({
            url: 'register.php',
            type: 'POST',
            data: $(this).serialize(),
            dataType: 'json',
            success: function (response) {
                if (response.status === 'success') {
                    Swal.fire("Success", "Registration complete!", "success").then(() => {
                        window.location.href = "login.php";
                    });
                } else {
                    Swal.fire("Error", response.message, "error");
                }
            }
        });
    });
});
</script>

</body>
</html>
